# endpoints/list_members.py
from flask import Blueprint, request, jsonify
from neo4j import GraphDatabase
from app import get_driver, neo4j_logger

bp = Blueprint('list_members', __name__)

@bp.route('/list_members', methods=['GET'])
def list_members():
    member_name = request.form.get('member_name')

    if not member_name:
        return jsonify({"error": "No member name provided"}), 400

    driver = get_driver()

    try:
        with driver.session() as session:
            result = session.run("""
                MATCH (m:Person {name: $memberName})-[*]-(n)
                RETURN m, n, collect(DISTINCT (m)-[r]->(n))
            """, memberName=member_name)

            data = {
                "nodes": [],
                "links": []
            }

            for record in result:
                node1 = record["m"]
                nodes = [record["n"]]

                # Add the first node
                if {"id": node1.id, "label": node1.labels[0], "name": node1.get("name")} not in data["nodes"]:
                    data["nodes"].append({"id": node1.id, "label": node1.labels[0], "name": node1.get("name")})

                # Add other nodes and links
                for node2 in nodes:
                    if {"id": node2.id, "label": node2.labels[0], "name": node2.get("name")} not in data["nodes"]:
                        data["nodes"].append({"id": node2.id, "label": node2.labels[0], "name": node2.get("name")})

                    for rel in record[2]:
                        if {"source": rel.start_node.id, "target": rel.end_node.id, "type": rel.type} not in data["links"]:
                            data["links"].append({"source": rel.start_node.id, "target": rel.end_node.id, "type": rel.type})

            return jsonify(data)

    except Exception as e:
        neo4j_logger.error(f"Error querying Neo4j: {e}")
        return jsonify({"error": str(e)}), 500

@bp.route('/get_member_names', methods=['GET'])
def get_member_names():
    driver = get_driver()

    try:
        with driver.session() as session:
            result = session.run("MATCH (p:Person) RETURN p.name AS name")
            members = [record['name'] for record in result]
            return jsonify(members)

    except Exception as e:
        neo4j_logger.error(f"Error fetching member names: {e}")
        return jsonify({"error": str(e)}), 500
